==> kubernetes-model-1.0.50-sources.jar: annotations/io/fabric8/openshift/api/model/DoneableOAuthAuthorizeTokenList.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.model.KubernetesResourceList;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.KubernetesResource;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.Fluent;

public class DoneableOAuthAuthorizeTokenList extends OAuthAuthorizeTokenListFluentImpl<DoneableOAuthAuthorizeTokenList> implements Doneable<OAuthAuthorizeTokenList>,OAuthAuthorizeTokenListFluent<DoneableOAuthAuthorizeTokenList>{


    private final OAuthAuthorizeTokenListBuilder builder;    private final Function<OAuthAuthorizeTokenList, OAuthAuthorizeTokenList> function;
    public DoneableOAuthAuthorizeTokenList ( Function<OAuthAuthorizeTokenList, OAuthAuthorizeTokenList> function){
    this.builder=new OAuthAuthorizeTokenListBuilder(this);this.function=function;
}
    public DoneableOAuthAuthorizeTokenList ( OAuthAuthorizeTokenList item,  Function<OAuthAuthorizeTokenList, OAuthAuthorizeTokenList> function){
    this.builder=new OAuthAuthorizeTokenListBuilder(this);this.function=function;
}
    public DoneableOAuthAuthorizeTokenList ( OAuthAuthorizeTokenList item){
    this.builder=new OAuthAuthorizeTokenListBuilder(this, item);this.function=new Function<OAuthAuthorizeTokenList, OAuthAuthorizeTokenList>() {
    public OAuthAuthorizeTokenList apply(OAuthAuthorizeTokenList item) {
        return item;
    }
}
;
}

    public OAuthAuthorizeTokenList done(){
     return function.apply(builder.build());
}


}

==> kubernetes-model-1.0.51-sources.jar: annotations/io/fabric8/openshift/api/model/DoneableOAuthAuthorizeTokenList.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Builder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Visitable;
import io.fabric8.kubernetes.api.builder.Function;
import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import io.fabric8.kubernetes.api.model.Doneable;
import io.fabric8.kubernetes.api.builder.BaseFluent;

public class DoneableOAuthAuthorizeTokenList extends OAuthAuthorizeTokenListFluentImpl<DoneableOAuthAuthorizeTokenList> implements Doneable<OAuthAuthorizeTokenList>, OAuthAuthorizeTokenListFluent<DoneableOAuthAuthorizeTokenList>{


    private final OAuthAuthorizeTokenListBuilder builder;    private final Function<OAuthAuthorizeTokenList, OAuthAuthorizeTokenList> function;
    public DoneableOAuthAuthorizeTokenList ( Function<OAuthAuthorizeTokenList, OAuthAuthorizeTokenList> function){
    this.builder=new OAuthAuthorizeTokenListBuilder(this);this.function=function;
}
    public DoneableOAuthAuthorizeTokenList ( OAuthAuthorizeTokenList item,  Function<OAuthAuthorizeTokenList, OAuthAuthorizeTokenList> function){
    this.builder=new OAuthAuthorizeTokenListBuilder(this, item);this.function=function;
}
    public DoneableOAuthAuthorizeTokenList ( OAuthAuthorizeTokenList item){
    this.builder=new OAuthAuthorizeTokenListBuilder(this, item);this.function=new Function<OAuthAuthorizeTokenList, OAuthAuthorizeTokenList>() {
    public OAuthAuthorizeTokenList apply(OAuthAuthorizeTokenList item) {
        return item;
    }
}
;
}

    public OAuthAuthorizeTokenList done(){
     return function.apply(builder.build());
}


}
